@@ -9,11 +9,11 @@
 
   PROGRAMMERS:
 
-    martin.isenburg@rapidlasso.com  -  http://rapidlasso.com
+    info@rapidlasso.de  -  https://rapidlasso.de
 
   COPYRIGHT:
 
-    (c) 2007-2012, martin isenburg, rapidlasso - fast tools to catch reality
+    (c) 2007-2012, rapidlasso GmbH - fast tools to catch reality
 
     This is free software; you can redistribute and/or modify it under the
     terms of the GNU Lesser General Licence as published by the Free Software
@@ -31,6 +31,7 @@
 #include "lasreaderpipeon.hpp"
 
 #include "lasindex.hpp"
+#include "lascopc.hpp"
 #include "lasfilter.hpp"
 #include "lastransform.hpp"
 
@@ -43,7 +44,7 @@ BOOL LASreaderPipeOn::open(LASreader* lasreader)
 {
   if (lasreader == 0)
   {
-    REprintf( "ERROR: no lasreader\n");
+    REprintf("ERROR: no lasreader\n");
     return FALSE;
   }
 
@@ -89,14 +90,14 @@ BOOL LASreaderPipeOn::open(LASreader* lasreader)
 
   if (laswriterlas == 0)
   {
-    REprintf( "ERROR: allocating laswriterlas\n");
+    REprintf("ERROR: allocating laswriterlas\n");
     return FALSE;
   }
 
   /*if (!laswriterlas->open(stdout, &header))
   {
     delete laswriterlas;
-    REprintf( "ERROR: opening laswriterlas to stdout\n");
+    REprintf("ERROR: opening laswriterlas to stdout\n");
     return FALSE;
   }*/
 
@@ -118,6 +119,16 @@ LASindex* LASreaderPipeOn::get_index() const
   return (lasreader ? lasreader->get_index() : 0);
 }
 
+void LASreaderPipeOn::set_copcindex(COPCindex* copcindex)
+{
+  if (lasreader) lasreader->set_copcindex(copcindex);
+}
+
+COPCindex* LASreaderPipeOn::get_copcindex() const
+{
+  return (lasreader ? lasreader->get_copcindex() : 0);
+}
+
 void LASreaderPipeOn::set_filter(LASfilter* filter)
 {
   if (lasreader) lasreader->set_filter(filter);
@@ -143,6 +154,11 @@ BOOL LASreaderPipeOn::inside_rectangle(const F64 min_x, const F64 min_y, const F
   return (lasreader ? lasreader->inside_rectangle(min_x, min_y, max_x, max_y) : FALSE);
 }
 
+BOOL LASreaderPipeOn::inside_copc_depth(const U8 mode, const I32 depth, const F32 resolution)
+{
+  return (lasreader ? lasreader->inside_copc_depth(mode, depth, resolution) : FALSE);
+}
+
 I32 LASreaderPipeOn::get_format() const
 {
   return (lasreader ? lasreader->get_format() : LAS_TOOLS_FORMAT_DEFAULT);
